@@ -4,9 +4,9 @@ def q1(qn=0):
     from IPython.display import display, Image
     import os
     if not qn:
-        print(sorted(contents('q1')))
+        print(sorted(contents('qu1')))
         with path(
-                q1,
+                'qu1',
                 'q1_task1.png'
                 ) as pt:
             img = Image(filename=pt)
